@@ -6,8 +6,13 @@ from federation.entities.diaspora.mixins import DiasporaEntityMixin, DiasporaRel
 from federation.entities.diaspora.utils import format_dt, struct_to_xml
 from federation.utils.diaspora import get_private_endpoint, get_public_endpoint
 
+class DiasporaMentionMixin:
+    def pre_send(self):
+        # add curly braces to mentions
+        for mention in self._mentions:
+            self.raw_content = self.raw_content.replace('@'+mention, '@{'+mention+'}')
 
-class DiasporaComment(DiasporaRelayableMixin, Comment):
+class DiasporaComment(DiasporaMentionMixin, DiasporaRelayableMixin, Comment):
     """Diaspora comment."""
     _tag_name = "comment"
 
@@ -35,7 +40,7 @@ class DiasporaImage(DiasporaEntityMixin, Image):
     _tag_name = "photo"
 
 
-class DiasporaPost(DiasporaEntityMixin, Post):
+class DiasporaPost(DiasporaMentionMixin, DiasporaEntityMixin, Post):
     """Diaspora post, ie status message."""
     _tag_name = "status_message"
 
