@@ -132,7 +132,10 @@ def handle_send(
                      ]
     :arg parent_user: (Optional) User object of the parent object, if there is one. This must be given for the
                       Diaspora protocol if a parent object exists, so that a proper ``parent_author_signature`` can
-                      be generated. If given, the payload will be sent as this user.
+                      be generated. If given, the payload will be sent as this user. For Activitypub, the
+                      parent_user's private key will be used to generate the http signature if the author_user
+                      is not a local user.
+
     :arg payload_logger: (Optional) Function to log the payloads with.
     """
     payloads = []
@@ -204,16 +207,6 @@ def handle_send(
                         logger.warning("handle_send - skipping activitypub due to failure to generate payload: %s", ex)
                         continue
                 payload = copy.copy(ready_payloads[protocol]["payload"])
-                if public:
-                    payload["to"] = [NAMESPACE_PUBLIC]
-                    payload["cc"] = [fid]
-                    if isinstance(payload.get("object"), dict):
-                        payload["object"]["to"] = [NAMESPACE_PUBLIC]
-                        payload["object"]["cc"] = [fid]
-                else:
-                    payload["to"] = [fid]
-                    if isinstance(payload.get("object"), dict):
-                        payload["object"]["to"] = [fid]
                 rendered_payload = json.dumps(payload).encode("utf-8")
             except Exception:
                 logger.error(
@@ -231,8 +224,10 @@ def handle_send(
                     }
                 )
                 continue
+            # The parent_user MUST be local
+            local_user = author_user if author_user.rsa_private_key else parent_user
             payloads.append({
-                "auth": get_http_authentication(author_user.rsa_private_key, f"{author_user.id}#main-key"),
+                "auth": get_http_authentication(local_user.rsa_private_key, f"{local_user.id}#main-key"),
                 "headers": {
                     "Content-Type": 'application/ld+json; profile="https://www.w3.org/ns/activitystreams"',
                 },
