@@ -4,8 +4,10 @@ INSTALLED_APPS = tuple()
 
 FEDERATION = {
     "base_url": "https://example.com",
+    "federation_id": "https://example.com/u/john/",
     "get_object_function": "federation.tests.django.utils.get_object_function",
     "get_private_key_function": "federation.tests.django.utils.get_private_key",
+    "get_public_key_function": "federation.tests.django.utils.get_public_key",
     "get_profile_function": "federation.tests.django.utils.get_profile",
     "matrix_config_function": "federation.tests.django.utils.matrix_config_func",
     "process_payload_function": "federation.tests.django.utils.process_payload",
