@@ -31,8 +31,8 @@ ACTIVITYPUB_COMMENT = {
   'atomUri': 'https://diaspodon.fr/users/jaywink/statuses/102356911717767237',
   'inReplyToAtomUri': 'https://dev.jasonrobinson.me/content/653bad70-41b3-42c9-89cb-c4ee587e68e4/',
   'conversation': 'tag:diaspodon.fr,2019-06-28:objectId=2347687:objectType=Conversation',
-  'content': '<p><span class="h-card"><a href="https://dev.jasonrobinson.me/u/jaywink/" class="u-url mention">@<span>jaywink</span></a></span> boom</p>',
-  'contentMap': {'en': '<p><span class="h-card"><a href="https://dev.jasonrobinson.me/u/jaywink/" class="u-url mention">@<span>jaywink</span></a></span> boom</p>'},
+  'content': '<p><span class="h-card"><a class="u-url mention" href="https://dev.jasonrobinson.me/u/jaywink/">@<span>jaywink</span></a></span> boom</p>',
+  'contentMap': {'en': '<p><span class="h-card"><a class="u-url mention" href="https://dev.jasonrobinson.me/u/jaywink/">@<span>jaywink</span></a></span> boom</p>'},
   'attachment': [],
   'tag': [{'type': 'Mention',
     'href': 'https://dev.jasonrobinson.me/p/d4574854-a5d7-42be-bfac-f70c16fcaa97/',
@@ -128,6 +128,85 @@ ACTIVITYPUB_PROFILE = {
   }
 }
 
+ACTIVITYPUB_REMOTE_PROFILE = {
+ "@context": ["https://www.w3.org/ns/activitystreams",
+              "https://w3id.org/security/v1",
+              {"Curve25519Key": "toot:Curve25519Key",
+               "Device": "toot:Device",
+               "Ed25519Key": "toot:Ed25519Key",
+               "Ed25519Signature": "toot:Ed25519Signature",
+               "EncryptedMessage": "toot:EncryptedMessage",
+               "PropertyValue": "schema:PropertyValue",
+               "alsoKnownAs": {"@id": "as:alsoKnownAs", "@type": "@id"},
+               "cipherText": "toot:cipherText",
+               "claim": {"@id": "toot:claim", "@type": "@id"},
+               "deviceId": "toot:deviceId",
+               "devices": {"@id": "toot:devices", "@type": "@id"},
+               "discoverable": "toot:discoverable",
+               "featured": {"@id": "toot:featured", "@type": "@id"},
+               "featuredTags": {"@id": "toot:featuredTags", "@type": "@id"},
+               "fingerprintKey": {"@id": "toot:fingerprintKey", "@type": "@id"},
+               "focalPoint": {"@container": "@list", "@id": "toot:focalPoint"},
+               "identityKey": {"@id": "toot:identityKey", "@type": "@id"},
+               "manuallyApprovesFollowers": "as:manuallyApprovesFollowers",
+               "messageFranking": "toot:messageFranking",
+               "messageType": "toot:messageType",
+               "movedTo": {"@id": "as:movedTo", "@type": "@id"},
+               "publicKeyBase64": "toot:publicKeyBase64",
+               "schema": "http://schema.org#",
+               "suspended": "toot:suspended",
+               "toot": "http://joinmastodon.org/ns#",
+               "value": "schema:value"}],
+ "attachment": [{"name": "OS", "type": "PropertyValue", "value": "Manjaro"},
+                {"name": "Self Hosting",
+                 "type": "PropertyValue",
+                 "value": "Matrix HS, Nextcloud"}],
+ "devices": "https://fosstodon.org/users/astdenis/collections/devices",
+ "discoverable": True,
+ "endpoints": {"sharedInbox": "https://fosstodon.org/inbox"},
+ "featured": "https://fosstodon.org/users/astdenis/collections/featured",
+ "featuredTags": "https://fosstodon.org/users/astdenis/collections/tags",
+ "followers": "https://fosstodon.org/users/astdenis/followers",
+ "following": "https://fosstodon.org/users/astdenis/following",
+ "icon": {"mediaType": "image/jpeg",
+          "type": "Image",
+          "url": "https://cdn.fosstodon.org/accounts/avatars/000/252/976/original/09b7067cde009950.jpg"},
+ "id": "https://fosstodon.org/users/astdenis",
+ "image": {"mediaType": "image/jpeg",
+           "type": "Image",
+           "url": "https://cdn.fosstodon.org/accounts/headers/000/252/976/original/555a1ac1819e4e7f.jpg"},
+ "inbox": "https://fosstodon.org/users/astdenis/inbox",
+ "manuallyApprovesFollowers": False,
+ "name": "Alain",
+ "outbox": "https://fosstodon.org/users/astdenis/outbox",
+ "preferredUsername": "astdenis",
+ "publicKey": {"id": "https://fosstodon.org/users/astdenis#main-key",
+               "owner": "https://fosstodon.org/users/astdenis",
+               "publicKeyPem": "-----BEGIN PUBLIC KEY-----\n"
+                               "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuaoIq/b+aUNqGAJNYF76\n"
+                               "WY8tk49Vb1udyb7X+oseBXYtOwCDGfbZMalnFfqur1bAzogkKzuyjCeA3BfVs6R3\n"
+                               "Cll897kUveMNHVc24pslhOx5ZzwpNT8e4q97dNaeHWLSLH5H+4JJGbeoD23G5SaY\n"
+                               "9ZKt5iP+qRUlO/kSsUPwqsX9i2qSEqzwDiSvyRYhvvx4O588cUaaY9rAliLgtc/P\n"
+                               "4EID3v6Edexe2QosUaghwGbb8zZWsYq0O4Umn2QMN4LzmQ0FjP+lq1TFX8FkGDZH\n"
+                               "lnP+AMEQMyuac9Yb12t4RwvdsAIk4MXhAKvutMJm/X1GVQIyrsLEmvAO3rgk8dMr\n"
+                               "6QIDAQAB\n"
+                               "-----END PUBLIC KEY-----\n"},
+ "published": "2020-07-25T00:00:00Z",
+ "summary": "<p>Linux user and sysadmin since 1994, retired from the HPC field "
+            "since 2019.</p><p>Utilisateur et sysadmin Linux depuis 1994, "
+            "retraité du domaine du CHP depuis 2019.</p>",
+ "tag": [],
+ "type": "Person",
+ "url": "https://fosstodon.org/@astdenis"
+}
+
+ACTIVITYPUB_COLLECTION = {
+ "@context": "https://www.w3.org/ns/activitystreams",
+ "id": "https://diaspodon.fr/users/jaywink/followers",
+ "totalItems": 231,
+ "type": "OrderedCollection"
+}
+
 ACTIVITYPUB_PROFILE_INVALID = {
   "@context": [
     "https://www.w3.org/ns/activitystreams",
@@ -235,7 +314,8 @@ ACTIVITYPUB_RETRACTION = {
     },
 }
 
-ACTIVITYPUB_RETRACTION_SHARE = {'@context': 'https://www.w3.org/ns/activitystreams',
+ACTIVITYPUB_RETRACTION_SHARE = {
+ '@context': ['https://www.w3.org/ns/activitystreams',{"ostatus":"http://ostatus.org#","atomUri":"ostatus:atomUri"}],
  'id': 'https://mastodon.social/users/jaywink#announces/102571932479036987/undo',
  'type': 'Undo',
  'actor': 'https://mastodon.social/users/jaywink',
@@ -255,7 +335,7 @@ ACTIVITYPUB_RETRACTION_SHARE = {'@context': 'https://www.w3.org/ns/activitystrea
   'signatureValue': 'erI90OrrLqK1DiTqb4OO72XLcE7m74Fs4cH6s0plKKELHa7BZFQmtQYXKEgA9LwIUdSRrIurAUiaDWAw2sQZDg7opYo9x3z+GJDMZ3KxhBND7iHO8ZeGhV1ZBBKUMuBb3BfhOkd3ADp+RQ/fHcw6kOcViV2VsQduinAgQRpiutmGCLd/7eshqSF/aL4tFoAOyCskkm/5JDMNp2nnHNoXXJ+SZf7a8C6YPNDxWd7GzyQNeWkTBBdCJBPvS4HI0wQrTWemBvy6uP8k5QQ7FnqrrRrk/7zrcibFSInuYxiRTRV++rQ3irIbXNtoLhWQd36Iu5U22BclmkS1AAVBDUIj8w=='}}
 
 ACTIVITYPUB_SHARE = {
-    '@context': 'https://www.w3.org/ns/activitystreams',
+    '@context': ['https://www.w3.org/ns/activitystreams',{"ostatus":"http://ostatus.org#","atomUri":"ostatus:atomUri"}],
     'id': 'https://mastodon.social/users/jaywink/statuses/102560701449465612/activity',
     'type': 'Announce',
     'actor': 'https://mastodon.social/users/jaywink',
@@ -312,7 +392,7 @@ ACTIVITYPUB_POST = {
  'published': '2019-06-29T21:08:45Z',
  'to': 'https://www.w3.org/ns/activitystreams#Public',
  'cc': ['https://diaspodon.fr/users/jaywink/followers',
-  'https://dev.jasonrobinson.me/p/d4574854-a5d7-42be-bfac-f70c16fcaa97/'],
+     'https://fosstodon.org/users/astdenis'],
  'object': {'id': 'https://diaspodon.fr/users/jaywink/statuses/102356911717767237',
   'type': 'Note',
   'summary': None,
@@ -322,13 +402,13 @@ ACTIVITYPUB_POST = {
   'attributedTo': 'https://diaspodon.fr/users/jaywink',
   'to': 'https://www.w3.org/ns/activitystreams#Public',
   'cc': ['https://diaspodon.fr/users/jaywink/followers',
-   'https://dev.jasonrobinson.me/p/d4574854-a5d7-42be-bfac-f70c16fcaa97/'],
+      'https://fosstodon.org/users/astdenis'],
   'sensitive': False,
   'atomUri': 'https://diaspodon.fr/users/jaywink/statuses/102356911717767237',
   'inReplyToAtomUri': None,
   'conversation': 'tag:diaspodon.fr,2019-06-28:objectId=2347687:objectType=Conversation',
-  'content': '<p><span class="h-card"><a href="https://dev.jasonrobinson.me/u/jaywink/" class="u-url mention">@<span>jaywink</span></a></span> boom</p>',
-  'contentMap': {'en': '<p><span class="h-card"><a href="https://dev.jasonrobinson.me/u/jaywink/" class="u-url mention">@<span>jaywink</span></a></span> boom</p>'},
+  'content': '<p><span class="h-card"><a class="u-url mention" href="https://dev.jasonrobinson.me/u/jaywink/">@<span>jaywink</span></a></span> boom</p>',
+  'contentMap': {'en': '<p><span class="h-card"><a class="u-url mention" href="https://dev.jasonrobinson.me/u/jaywink/">@<span>jaywink</span></a></span> boom</p>'},
   'attachment': [],
   'tag': [{'type': 'Mention',
     'href': 'https://dev.jasonrobinson.me/p/d4574854-a5d7-42be-bfac-f70c16fcaa97/',
@@ -524,12 +604,12 @@ ACTIVITYPUB_POST_WITH_SOURCE_BBCODE = {
   'atomUri': 'https://diaspodon.fr/users/jaywink/statuses/102356911717767237',
   'inReplyToAtomUri': None,
   'conversation': 'tag:diaspodon.fr,2019-06-28:objectId=2347687:objectType=Conversation',
-  'content': '<p><span class="h-card"><a href="https://dev.jasonrobinson.me/u/jaywink/" class="u-url mention">@<span>jaywink</span></a></span> boom</p>',
+  'content': '<p><span class="h-card"><a class="u-url mention" href="https://dev.jasonrobinson.me/u/jaywink/">@<span>jaywink</span></a></span> boom</p>',
   'source': {
       'content': "[url=https://example.com]jaywink[/url] boom",
       'mediaType': "text/bbcode",
   },
-  'contentMap': {'en': '<p><span class="h-card"><a href="https://dev.jasonrobinson.me/u/jaywink/" class="u-url mention">@<span>jaywink</span></a></span> boom</p>'},
+  'contentMap': {'en': '<p><span class="h-card"><a class="u-url mention" href="https://dev.jasonrobinson.me/u/jaywink/">@<span>jaywink</span></a></span> boom</p>'},
   'attachment': [],
   'tag': [{'type': 'Mention',
     'href': 'https://dev.jasonrobinson.me/p/d4574854-a5d7-42be-bfac-f70c16fcaa97/',
@@ -545,7 +625,17 @@ ACTIVITYPUB_POST_WITH_SOURCE_BBCODE = {
   'signatureValue': 'SjDACS7Z/Cb1SEC3AtxEokID5SHAYl7kpys/hhmaRbpXuFKCxfj2P9BmH8QhLnuam3sENZlrnBOcB5NlcBhIfwo/Xh242RZBmPQf+edTVYVCe1j19dihcftNCHtnqAcKwp/51dNM/OlKu2730FrwvOUXVIPtB7iVqkseO9TRzDYIDj+zBTksnR/NAYtq6SUpmefXfON0uW3N3Uq6PGfExJaS+aeqRf8cPGkZFSIUQZwOLXbIpb7BFjJ1+y1OMOAJueqvikUprAit3v6BiNWurAvSQpC7WWMFUKyA79/xtkO9kIPA/Q4C9ryqdzxZJ0jDhXiaIIQj2JZfIADdjLZHJA=='}
 }
 
-ACTIVITYPUB_POST_OBJECT = {
+ACTIVITYPUB_POST_OBJECT = {'@context': ['https://www.w3.org/ns/activitystreams',
+      {'ostatus': 'http://ostatus.org#',
+       'atomUri': 'ostatus:atomUri',
+       'inReplyToAtomUri': 'ostatus:inReplyToAtomUri',
+       'conversation': 'ostatus:conversation',
+       'sensitive': 'as:sensitive',
+       'Hashtag': 'as:Hashtag',
+       'toot': 'http://joinmastodon.org/ns#',
+       'Emoji': 'toot:Emoji',
+       'focalPoint': {'@container': '@list', '@id': 'toot:focalPoint'},
+       'blurhash': 'toot:blurhash'}],
     'id': 'https://diaspodon.fr/users/jaywink/statuses/102356911717767237',
     'type': 'Note',
     'summary': None,
