@@ -5,13 +5,13 @@ from federation.tests.fixtures.keys import get_dummy_private_key
 def test_signing_request():
     key = get_dummy_private_key()
     auth = get_http_authentication(key, "dummy_key_id")
-    assert auth.algorithm == 'rsa-sha256'
-    assert auth.headers == [
+    assert auth.header_signer.headers == [
         '(request-target)',
         'user-agent',
         'host',
         'date',
+        'digest',
     ]
-    assert auth.key == key.exportKey()
-    assert auth.key_id == 'dummy_key_id'
+    assert auth.header_signer.secret == key.exportKey()
+    assert 'dummy_key_id' in auth.header_signer.signature_template
 
