@@ -152,6 +152,7 @@ def parse_profile_from_hcard(hcard: str, handle: str):
         public=True,
         id=handle,
         handle=handle,
+        finger=handle,
         guid=_get_element_text_or_none(doc, ".uid"),
         public_key=_get_element_text_or_none(doc, ".key"),
         username=handle.split('@')[0],
@@ -161,8 +162,8 @@ def parse_profile_from_hcard(hcard: str, handle: str):
 
 
 def retrieve_and_parse_content(
-        id: str, guid: str, handle: str, entity_type: str, sender_key_fetcher: Callable[[str], str]=None,
-):
+        id: str, guid: str, handle: str, entity_type: str, cache: bool=True, 
+        sender_key_fetcher: Callable[[str], str]=None):
     """Retrieve remote content and return an Entity class instance.
 
     This is basically the inverse of receiving an entity. Instead, we fetch it, then call "handle_receive".
@@ -175,7 +176,7 @@ def retrieve_and_parse_content(
         return
     _username, domain = handle.split("@")
     url = get_fetch_content_endpoint(domain, entity_type.lower(), guid)
-    document, status_code, error = fetch_document(url)
+    document, status_code, error = fetch_document(url, cache=cache)
     if status_code == 200:
         request = RequestType(body=document)
         _sender, _protocol, entities = handle_receive(request, sender_key_fetcher=sender_key_fetcher)
